#!/bin/sh

CONFIG="/etc/n900_lights.conf"
MODPROBE="/sbin/modprobe"
PANEL=acx565akm
BACKLIGHT="90"
DIMRATIO="2"
LEDDEV="lp5523"
KBLEDCHANS="kb1 kb2 kb3 kb4 kb5 kb6"
KBLEDTRIG="gpio"
KBLEDS="64"

[ -f "$CONFIG" ] && . "$CONFIG"

magic() {
	case $1 in
		backlight)
		  [ -f /sys/class/backlight/$PANEL/brightness ] || $MODPROBE panel_$PANEL || return 1
		  ;;
		kbleds)
		  KBLEDFIRSTCHAN=${KBLEDCHANS%% *}
		  [ -d /sys/class/leds/$LEDDEV\:$KBLEDFIRSTCHAN ] || $MODPROBE leds_$LEDDEV || return 1
		  [ "$KBLEDTRIG" == "gpio" ] \
			&& grep -q gpio /sys/class/leds/$LEDDEV\:$KBLEDFIRSTCHAN/trigger \
			|| $MODPROBE ledtrig_gpio || KBLEDTRIG="none"
		  ;;
	esac
}

backlight() {

	magic backlight || return 1

	case $1 in
		on)
		  BRIGHTNESS=$BACKLIGHT
		  ;;
		off)
		  BRIGHTNESS=0
		  ;;
		dim)
		  BRIGHTNESS=$[BACKLIGHT / DIMRATIO]
		  ;;
		*)
		  return 1
	esac

	echo $BRIGHTNESS > /sys/class/backlight/$PANEL/brightness
}

kbleds() {

	magic kbleds || return 1

	case $1 in
		off)
		  for CHAN in $KBLEDCHANS
		  do
			[ $KBLEDTRIG == "gpio" ] && \
			  echo none > /sys/class/leds/$LEDDEV\:$CHAN/trigger
			echo 0 > /sys/class/leds/$LEDDEV\:$CHAN/brightness
		  done
		  ;;
		on)
		  case "$KBLEDTRIG" in
			gpio)
			  for CHAN in $KBLEDCHANS
			  do
				echo gpio > \
				  /sys/class/leds/$LEDDEV\:$CHAN/trigger
				echo 71 > \
				  /sys/class/leds/$LEDDEV\:$CHAN/gpio
				echo $KBLEDS > \
				  /sys/class/leds/$LEDDEV\:$CHAN/desired_brightness
				echo 1 > \
				  /sys/class/leds/$LEDDEV\:$CHAN/inverted
			  done
			  ;;
			none)
			  for CHAN in $KBLEDCHANS
			  do
				echo $KBLEDS > \
				  /sys/class/leds/$LEDDEV\:$CHAN/brightness
			  done
		  esac
		  ;;
		*)
		  return 1
	esac
}

case "$1" in
	start)
		backlight on
		kbleds on
		;;
	stop)
		kbleds off
		backlight off
		;;
	backlight|bl)
		backlight $2
		;;
	kbleds|kb)
		kbleds $2
		;;
	*)
		echo $"Usage: $0 {start|stop|backlight on/off/dim|kbleds on/off}"
		exit 1
esac

exit 0
